@@ -55,6 +55,7 @@ var _ = Describe("Process", func() {
 				Expect(req.Header.Get("Authorization")).To(BeEmpty())
 				Expect(req.Header.Get("X-Forwarded-Roles")).To(BeEmpty())
 				Expect(req.Header.Get("X-OCP-NS")).To(BeEmpty())
+				Expect(req.Header.Get("X-OCP-NSUID")).To(BeEmpty())
 			})
 			It("should store subject into the request context", func() {
 				Expect(req.Context().Value(handlers.SubjectKey)).To(Equal("CN=foo,OU=org-unit,O=org"))
@@ -79,6 +80,7 @@ var _ = Describe("Process", func() {
 		})
 	})
 
+	// Context("when a bearer token without certs is provided and it does not error", func() {
 	Context("when certs are not provided and it does not error", func() {
 		var otherCacheEntry *rolesProjects
 		BeforeEach(func() {
@@ -101,9 +103,11 @@ var _ = Describe("Process", func() {
 				projects: []apis.Project{
 					apis.Project{
 						Name: "projecta",
+						UUID: "projectauuid",
 					},
 					apis.Project{
 						Name: "projectb",
+						UUID: "projectbuuid",
 					},
 				},
 			}
@@ -166,10 +170,15 @@ var _ = Describe("Process", func() {
 				Expect(ok).To(BeTrue(), fmt.Sprintf("Expected a user's projects to be added to be proxy headers: %v", req.Header))
 				Expect(entries).To(Equal([]string{"\"projecta\",\"projectb\""}))
 			})
+			It("should add a user's project uids to the request", func() {
+				entries, ok := req.Header["X-Ocp-Nsuid"]
+				Expect(ok).To(BeTrue(), fmt.Sprintf("Expected a project uids to be added to be proxy headers: %v", req.Header))
+				Expect(entries).To(Equal([]string{"projectauuid,projectbuuid"}))
+			})
 			It("should store username, roles and project in request context", func() {
 				wantProjects := []apis.Project{
-					{Name: "projecta"},
-					{Name: "projectb"},
+					{Name: "projecta", UUID: "projectauuid"},
+					{Name: "projectb", UUID: "projectbuuid"},
 				}
 				wantRoles := []string{"roleA", "roleB"}
 				Expect(req.Context().Value(handlers.UsernameKey)).To(Equal("myname"))
@@ -177,7 +186,7 @@ var _ = Describe("Process", func() {
 				Expect(req.Context().Value(handlers.RolesKey)).To(ConsistOf(wantRoles))
 			})
 
-			Context("and has the spec'd default role with predefined roles", func() {
+			Context("and has the spec'd default role", func() {
 
 				BeforeEach(func() {
 					req.Header.Set("Authorization", "Bearer somebearertoken")
@@ -187,38 +196,14 @@ var _ = Describe("Process", func() {
 					Expect(err).To(BeNil())
 				})
 
-				It("should not update the request to include the default role", func() {
+				It("should update the request to only include the admin role", func() {
 					entries, ok := req.Header["X-Forwarded-Roles"]
 					Expect(ok).To(BeTrue(), fmt.Sprintf("Expected 'X-Forwarded-Roles' in the headers: %v", req.Header))
-					Expect(entries).To(Equal([]string{"roleA,roleB"}), "Exp. to not apply the default role")
-				})
-
-				It("should not store default role in request context", func() {
-					wantRoles := []string{"roleA", "roleB"}
-					Expect(req.Context().Value(handlers.RolesKey)).To(ConsistOf(wantRoles))
-				})
-			})
-
-			Context("and has the spec'd default role without predefined roles", func() {
-
-				BeforeEach(func() {
-					cacheEntry.roles = map[string]struct{}{}
-					req.Header.Set("Authorization", "Bearer somebearertoken")
-
-					handler.config.AuthAdminRole = ""
-					handler.config.AuthDefaultRole = "project_reader"
-					req, err = handler.Process(req)
-					Expect(err).To(BeNil())
-				})
-
-				It("should update the request to only include the default role", func() {
-					entries, ok := req.Header["X-Forwarded-Roles"]
-					Expect(ok).To(BeTrue(), fmt.Sprintf("Expected 'X-Forwarded-Roles' in the headers: %v", req.Header))
-					Expect(entries).To(Equal([]string{"project_reader"}), "Exp. to the default role to apply")
+					Expect(entries).To(Equal([]string{"project_reader,roleA,roleB"}), "Exp. to the default role to apply")
 				})
 
 				It("should store default role in request context", func() {
-					wantRoles := []string{"project_reader"}
+					wantRoles := []string{"project_reader", "roleA", "roleB"}
 					Expect(req.Context().Value(handlers.RolesKey)).To(ConsistOf(wantRoles))
 				})
 			})
